@@ -1,11 +1,11 @@
 from matchit import Router
 
-r = Router()
+r = Router[str]()
 r.insert("/test/{id}", "test_id")
 
 res = r.at("/test/1")
 
-assert res.route == "test_id"
+assert res.value == "test_id"
 assert res.params == {"id": "1"}
 
 try:
